==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>グラフィックスビュー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>色</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>グラフィックスビュー</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>背景:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>カーソル</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>十字線:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>非アクティブな十字線:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>原点</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>相対ゼロ:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>メタグリッド:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>選択</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>選択ボックスの境界:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>選択ボックス:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>クロスセレクションボックス:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>スナップツール</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>情報</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>補助輪郭:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>ズームボックス:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">非アクティブな十字線:</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>Origin:</source>
        <translation>原点:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="obsolete">相対ゼロ:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">基準点:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>グリッド:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">メタグリッド:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="obsolete">ズームボックス:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translation type="obsolete">選択:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="obsolete">選択ボックスの境界:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="obsolete">選択ボックス:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translation type="obsolete">クロスセレクションボックス:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translation type="obsolete">補助輪郭:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translation type="obsolete">情報ラベル背景:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translation type="obsolete">情報ラベルフォント:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translation type="obsolete">計測ツール:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>グラフィックビュー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>色</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>グラフィックビュー</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>背景:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>カーソル</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>十字線:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>非アクティブな十字線:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>原点</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>相対ゼロ:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>メタグリッド:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>選択</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>主要な選択色:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>2番目の選択色を使用する</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>2番目の選択色:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>ドラッグ可能な基準点:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>2番目の基準点:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>選択ボックスの境界:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>選択ボックス:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>クロスセレクションボックス:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>開始点:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>終了点:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>スナップツール</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>スナップラベル:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>情報</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>測定とラベル:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>描画ツール</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>補助輪郭:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>拡大ツール</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>ズームボックス:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">非アクティブな十字線:</translation>
    </message>
    <message>
        <location line="-616"/>
        <source>Origin:</source>
        <translation>原点:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="obsolete">相対ゼロ:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">基準点:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>グリッド:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">メタグリッド:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="obsolete">ズームボックス:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translation type="obsolete">選択:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="obsolete">選択ボックスの境界:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="obsolete">選択ボックス:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translation type="obsolete">クロスセレクションボックス:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translation type="obsolete">補助輪郭:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translation type="obsolete">情報ラベル背景:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translation type="obsolete">情報ラベルフォント:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translation type="obsolete">計測ツール:</translation>
    </message>
</context>
</TS>
